PyBitCrypt

This is an encrypting and decrypting module. 
It uses a key to shift the letters by the key.

Encoding:

import PyBitCrypt as pbc

key = 'SampleKey1!'

text = 'SampleText1!'

encoded = pbc.encrypt(key, text)



Decoding:



import PyBitCrypt as pbc

key = 'SampleKey1!'

text = 'SampleText1!'

encoded = pbc.encrypt(key, text)






Enjoy!